aboutsummaryrefslogtreecommitdiff
path: root/engines/mads/screen.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/mads/screen.cpp')
-rw-r--r--engines/mads/screen.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/mads/screen.cpp b/engines/mads/screen.cpp
index 25623bc215..683a56705a 100644
--- a/engines/mads/screen.cpp
+++ b/engines/mads/screen.cpp
@@ -354,10 +354,10 @@ void ScreenObjects::check(bool scanFlag) {
slot._flags = IMG_ERASE;
}
- // Any background animation
- scene.backgroundAnimation();
+ // Any background animation in the user interface
+ userInterface.doBackgroundAnimation();
- // Handle animating the selected inventory animation
+ // Handle animating the selected inventory item
userInterface.inventoryAnim();
// Set the base time